import axios from "../../utils/axios";

export function GetList(param){
    return axios({
        url: "/sys/user/list",
        method: "post",
        data:param
    });
}

export function Insert(param){
    return axios({
        url: "/sys/user/insert",
        method: "post",
        data:param
    });
}
export function Update(param){
    return axios({
        url: "/sys/user/update",
        method: "post",
        data:param
    });
}
export function Detail(id){
    return axios({
        url: "/sys/user/detail",
        method: "post",
        params:{id}
    });
}

export function Delete(id){
    return axios({
        url: "/sys/user/delete",
        method: "post",
        params:{id}
    });
}
export function GetRoleList(){
    return axios({
        url: "/sys/role/list",
        method: "post",
        data: {page:1,limit:1000}
    });
}
